QueryResult

Struct QueryResult 

pub struct QueryResult {
    pub query: Query,
    pub inner: RangeQueryResult<Sample, SampleMetrics>,
}
This holds the result of a query to the database. The result can be several things, depending upon query type. It can be min/max/mean slices, or single values, if the data is present at the proper resolution.

Fields

query: Queryinner: RangeQueryResult<Sample, SampleMetrics>

Implementations

Source

impl QueryResult

pub fn len(&self) -> usize

Examples found in repository?
examples/perf.rs (line 53)
42fn do_query(db: &TsDb) {
43    // Query the data
44    println!("Querying the database!");
45
46    let query = Query::create()
47        .start(TimeStamp::new(0.0))
48        .end(TimeStamp::new(1000.0))
49        .build();
50    let result = db.query("fu", query);
51
52    println!("Got result: {:?}", result.query);
53    println!("Num result: {:?}", result.len());
54    // let raw_samples = result.into_vec();
55    // println!("Raw samples: {}", raw_samples.len());
56}